@@ -105,6 +105,11 @@ def main():
 
             output.ANSI = True
 
+        # filter environment
+        filterenv = config.get((), "filters-environment", True)
+        if not filterenv:
+            util.compile_expression = util.compile_expression_raw
+
         # format string separator
         separator = config.get((), "format-separator")
         if separator:
@@ -145,6 +150,10 @@ def main():
 
             log.debug("Configuration Files %s", config._files)
 
+        if args.print_traffic:
+            import requests
+            requests.packages.urllib3.connection.HTTPConnection.debuglevel = 1
+
         # extractor modules
         modules = config.get(("extractor",), "modules")
         if modules is not None:
@@ -229,6 +238,13 @@ def main():
                 return config.open_extern()
 
         else:
+            input_files = config.get((), "input-files")
+            if input_files:
+                for input_file in input_files:
+                    if isinstance(input_file, str):
+                        input_file = (input_file, None)
+                    args.input_files.append(input_file)
+
             if not args.urls and not args.input_files:
                 parser.error(
                     "The following arguments are required: URL\n"
@@ -240,6 +256,9 @@ def main():
                 if config.get(("output",), "fallback", True):
                     jobtype.handle_url = \
                         staticmethod(jobtype.handle_url_fallback)
+            elif args.dump_json:
+                jobtype = job.DataJob
+                jobtype.resolve = args.dump_json - 1
             else:
                 jobtype = args.jobtype or job.DownloadJob
 
@@ -299,6 +318,8 @@ def main():
                     else:
                         input_manager.success()
 
+                except exception.StopExtraction:
+                    pass
                 except exception.TerminateExtraction:
                     pass
                 except exception.RestartExtraction:
