@@ -22,6 +22,7 @@ modules = [
     "8chan",
     "8muses",
     "adultempire",
+    "agnph",
     "architizer",
     "artstation",
     "aryion",
@@ -33,6 +34,7 @@ modules = [
     "bunkr",
     "catbox",
     "chevereto",
+    "cien",
     "comicvine",
     "cyberdrop",
     "danbooru",
@@ -42,7 +44,6 @@ modules = [
     "e621",
     "erome",
     "exhentai",
-    "fallenangels",
     "fanbox",
     "fanleaks",
     "fantia",
@@ -84,6 +85,7 @@ modules = [
     "keenspot",
     "kemonoparty",
     "khinsider",
+    "koharu",
     "komikcast",
     "lensdump",
     "lexica",
